# About

This is a personal collection of Python and IDL routines for my research
in Space Plasma Physics, organized into packages. Some are more
well-documented than others. Please use them at your discretion.

## Installation

Ensure `micromamba` is recognized in PATH. Then just run
```
make install
```
